train_cmd.c
changeset 1698 bf364c664a60
parent 1685 b9cfe79393c0
child 1752 cdbfb2f23e72
--- a/train_cmd.c	Thu Apr 14 22:59:49 2005 +0000
+++ b/train_cmd.c	Fri Apr 15 13:48:08 2005 +0000
@@ -1672,12 +1672,17 @@
 		assert(trackdir != 0xff);
 
 		ftd = NPFRouteToStationOrTile(tile - TileOffsByDir(enterdir), trackdir, &fstd, TRANSPORT_RAIL, v->owner);
-		if (ftd.best_bird_dist != 0 || ftd.best_trackdir == 0xff) {
-			/* Not found, or we are already there. Just do something */
+
+		if (ftd.best_trackdir == 0xff) {
+			/* We are already at our target. Just do something */
 			//TODO: maybe display error?
 			//TODO: go straight ahead if possible?
 			best_track = FIND_FIRST_BIT(bits);
 		} else {
+			/* If ftd.best_bird_dist is 0, we found our target and ftd.best_trackdir contains
+			the direction we need to take to get there, if ftd.best_bird_dist is not 0,
+			we did not find our target, but ftd.best_trackdir contains the direction leading
+			to the tile closest to our target. */
 			/* Discard enterdir information, making it a normal track */
 			best_track = ftd.best_trackdir & 7; /* TODO: Wrapper function? */
 		}